@@ -15,13 +15,19 @@ VB_COMMAND_LIST_HOSTDVDS='%s list hostdvds'%(VB_COMMAND)
 VB_COMMAND_LIST_DVDS='%s list dvds'%(VB_COMMAND)
 VB_COMMAND_LIST_HDDS='%s list hdds'%(VB_COMMAND)
 VB_COMMAND_SHOWVMINFO='%s showvminfo'%(VB_COMMAND)
+VB_COMMAND_SHOWVDIINFO='%s showvdiinfo'%(VB_COMMAND)
 VB_COMMAND_STARTVM='%s startvm'%(VB_COMMAND)
 VB_COMMAND_CONTROLVM='%s controlvm'%(VB_COMMAND)
+VB_COMMAND_CREATEVM='%s createvm'%(VB_COMMAND)
+VB_COMMAND_CREATEVDI='%s createvdi'%(VB_COMMAND)
+VB_COMMAND_MODIFYVM='%s modifyvm'%(VB_COMMAND)
+VB_COMMAND_REGISTERIMAGE='%s registerimage'%(VB_COMMAND)
 
 VB_RE_NAME=re.compile('(Name: *)(.*)')
 VB_RE_GUESTOS=re.compile('(Guest OS: *)(.*)')
 VB_RE_UUID=re.compile('(UUID: *)(.*)')
 VB_RE_UUID2=re.compile('.*(UUID: *)(.*)\)')
+VB_RE_UUID3=re.compile('(Disk image created. UUID: *)(.*)')
 VB_RE_CONFIGFILE=re.compile('(Config file: *)(.*)')
 VB_RE_MEMORYSIZE=re.compile('(Memory size: *)(.*)')
 VB_RE_VRAMSIZE=re.compile('(VRAM size: *)(.*)')
@@ -51,3 +57,10 @@ VB_RE_PATH=re.compile('(Path: *)(.*)')
 VB_RE_ACCESSIBLE=re.compile('(Accessible: *)(.*)')
 VB_RE_STORAGETYPE=re.compile('(Storage type: *)(.*)')
 VB_RE_USAGE=re.compile('(Usage: *)(.*)')
+VB_RE_SHAREDFOLDER_NAME=re.compile('(\')(.*)\',')
+VB_RE_SHAREDFOLDER_PATH=re.compile('.*(Host path: )\'(.*)\'')
+VB_RE_STATE_NAME=re.compile('( )(.*) \(')
+VB_RE_STATE_DATE=re.compile('(.*) \(since (.*)\)')
+VB_RE_REGISTERED=re.compile('(Registered: *)(.*)')
+VB_RE_SIZE=re.compile('(Size: *)(.*)')
+VB_RE_CURRENT_DISK_SIZE=re.compile('(Current size on disk: *)(.*)')
