@@ -4,6 +4,9 @@ vm - pyvb module that holds the implementation of all VM related abstractions.
 from pyvb.constants import *
 from pyvb.parser import *
 from pyvb.command import *
+from pyvb.sharedfolder import *
+from pyvb.state import *
+from pyvb.hdd import *
 
 class vbVmParser(vbParser):
     """A parser for parsing the command line output for VirtualBox VMs."""
@@ -49,31 +52,103 @@ class vbVmParser(vbParser):
         @rtype: List"""
         vms=[]
         for result in self._parse(file):
-            found_vm=vbVM(name=result['name'],\
-                          guestos=result['guestos'],\
-                          uuid=result['uuid'],\
-                          configfile=result['configfile'],\
-                          memorysize=result['memorysize'],\
-                          vramsize=result['vramsize'],\
-                          bootmenumode=result['bootmenumode'],\
-                          acpi=result['acpi'],\
-                          ioacpi=result['ioacpi'],\
-                          timeoffset=result['timeoffset'],\
-                          virtext=result['virtext'],\
-                          state=result['state'],\
-                          monitorcount=result['monitorcount'],\
-                          floppy=result['floppy'],\
-                          primarymaster=result['primarymaster'],\
-                          dvd=result['dvd'],\
-                          nic1=result['nic1'],\
-                          nic2=result['nic2'],\
-                          nic3=result['nic3'],\
-                          nic4=result['nic4'],\
-                          uart1=result['uart1'],\
-                          uart2=result['uart2'],\
-                          audio=result['audio'],\
-                          clipboardmode=result['clipboardmode'],\
-                          sharedfolders=result['sharedfolders'])
+            found_vm=vbVM()
+            try:
+                found_vm.setName(result['name'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setGuestos(result['guestos'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setUUID(result['uuid'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setConfigfile(result['configfile'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setMemorysize(result['memorysize'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setVramsize(result['vramsize'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setBootmenumode(result['bootmenumode'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setACPI(result['acpi'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setIOACPI(result['ioacpi'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setTimeoffset(result['timeoffset'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setVirtext(result['virtext'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setState(result['state'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setMonitorcount(result['monitorcount'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setFloppy(result['floppy'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setPrimarymaster(result['primarymaster'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setDVD(result['dvd'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setNIC1(result['nic1'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setNIC2(result['nic2'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setNIC3(result['nic3'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setNIC4(result['nic4'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setUART1(result['uart1'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setUART2(result['uart2'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setClipboardmode(result['clipboardmode'])
+            except KeyError:
+                pass
+            try:
+                found_vm.setSharedfolders(result['sharedfolders'])
+            except KeyError:
+                pass
             vms.append(found_vm)
         return vms
     
@@ -471,7 +546,8 @@ class vbVM:
         """Return the state attribute of this L{pyvb.vm.vbVM} instance.
         @return: The state attribute.
         @rtype: String"""
-        return self.state
+        parser=vbStateParser()
+        return parser.parse([' %s'%(self.state)])[0]
     
     def getMonitorcount(self):
         """Return the monitorcount attribute of this L{pyvb.vm.vbVM} instance.
@@ -553,14 +629,20 @@ class vbVM:
         command=VBCommand(command=cmd)
         parser=vbVmParser()
         command.run()
-        return parser._parseAdditional(command.read, VB_RE_NAME)
-        #return self.sharedfolders
+        result=parser._parseAdditional(command.read, VB_RE_NAME)
+        parser=vbSharedFolderParser()
+        return parser.parse(result)
     
     def getHDD(self):
         """Return the uuid of this machin's HDD.
         @return: The uuid of the HDD.
         @rtype: String"""
-        return vbVmParser().parseHddUUID(self.getPrimarymaster())
+        uuid=vbVmParser().parseHddUUID(self.getPrimarymaster())
+        parser=vbHddParser()
+        cmd='%s %s'%(VB_COMMAND_SHOWVDIINFO, uuid)
+        command=VBCommand(command=cmd)
+        command.run()
+        return parser.parseSingle(command.read)[0]
     
     def getStateName(self):
-        return vbVmParser().parseState(self.getState())[0]
\ No newline at end of file
+        return self.getState().getName()
\ No newline at end of file
